@@ -286,12 +286,15 @@ static int handle_txpower(struct nl80211_state *state,
 	NLA_PUT_U32(msg, NL80211_ATTR_WIPHY_TX_POWER_SETTING, type);
 
 	if (type != NL80211_TX_POWER_AUTOMATIC) {
+		char *endptr;
 		if (argc != 2) {
 			printf("Missing TX power level argument.\n");
 			return 2;
 		}
 
-		mbm = atoi(argv[1]);
+		mbm = strtol(argv[1], &endptr, 10);
+		if (!*endptr)
+			return 2;
 		NLA_PUT_U32(msg, NL80211_ATTR_WIPHY_TX_POWER_LEVEL, mbm);
 	} else if (argc != 1)
 		return 1;
